function obj = vna_connect(vna)
%VNA_CONNECT Verbindung zum VNA aufbauen
%   Kommunikation erfolgt mit SCPI-Befehlen
%   input arguments
%       vna             Bezeichnung des zu verwendenden VNAs
%                       untersttzt werden
%                       'none'  fr Testzwecke, Messwerte werden aus Datei gelesen
%                       'zvl'   National Instruments GPIB board, board index 0, 
%                               Rohde&Schwarz ZVL mit Option B10, primary address 20,
%                               Messwerte werden in Datei geschrieben
%                       'znle'  National Instruments GPIB board, board index 0, 
%                               Rohde&Schwarz ZNLE mit Option FPL1-B10, primary address 20,
%                               Messwerte werden in Datei geschrieben
%                       'zvb'   National Instruments GPIB board, board index 0, 
%                               Rohde&Schwarz ZVB, primary address 20,
%                               Messwerte werden in Datei geschrieben
%                       'fpc'   Rohde&Schwarz FPC1500 mit Option K42, 
%                               ber USB angeschlossen, Ressourcenname mittels
%                               instrhwinfo('visa','rs') ermitteln,
%                               Messwerte werden in Datei geschrieben
%   output arguments
%       obj             Instrument Object
%
%   Instrument Control Toolbox 
%       S. 1-23 bis 1-24
%       S. 3-20 bis 3-21
%       S. 5-31 bis 5-34
%
%   SCPI-Befehle 
%       *IDN?
%
%   28.08.2019          T. Weber    
%   29.11.2020          Untersttzung fr FPC1500 hinzugefgt

switch vna
    case 'none'
        % Dummy Object erzeugen
        obj.Name = 'none';
        
        disp('no VNA');
        
    case {'zvl','znle','zvb'}
        % Verbindung herstellen, groen Eingangspuffer konfigurieren
        obj = gpib('ni',0,20,'InputBufferSize',2^18,'Name',vna);
        fopen(obj);

        % Abfrage der Instrument Identification zum Prfen der Verbindung
        fprintf(obj,'*IDN?');
        disp(fscanf(obj));

    case 'fpc'
        obj = visa('rs','USB0::0x0AAD::0x01BB::102772::2::INSTR','InputBufferSize',2^18,'Name',vna);
        fopen(obj);
        
        % Abfrage der Instrument Identification zum Prfen der Verbindung
        fprintf(obj,'*IDN?');
        disp(fscanf(obj));
        
    otherwise
    	error('unsupported VNA');
        
end

end
